SoundList

Struct SoundList 

pub struct SoundList { /* private fields */ }
Play Sounds sequentially one after the other.

Only after a Sound has returned NextSample::Finished will the next Sound start playing.

If an Error is returned from a Sound it is dropped and the error is propagated to the caller. Calling next_sound again would continue with the next Sound in the list.

Implementations

Source

impl SoundList

pub fn new() -> Self

Create a new empty SoundList.

pub fn add(&mut self, sound: Box<dyn Sound>)

Add a Sound to be played after any existing sounds have Finished.

pub fn insert(&mut self, index: usize, sound: Box<dyn Sound>)

Inserts a sound at position index, shifting all elements after it to the right.

Panics

Panics if index > len.

pub fn clear(&mut self)

Stop all sounds including the currently playing one.

pub fn len(&self) -> usize

Returns the number of sounds currently in the list.